/* PROJECT-LEVEL WOMEN'S EMPOWERMENT IN AGRICULTURE INDEX (PRO-WEAI)
	DATA PREP DO-FILE - CREATE A-WEAI INDICATORS FROM PRO-WEAI DATA
	UDPATED AUGUST 2018
	CONTACT: ELENA MARTINEZ, E.MARTINEZ@CGIAR.ORG
	
	THIS DO-FILE CALCULATES THE A-WEAI INDICATORS FROM CLEAN PRO-WEAI DATA.
	VARIABLES SHOULD BE NAMED ACCORDING TO THE FILE "VARIABLE NAMES AND CODEBOOK FOR PILOT PRO-WEAI SURVEY MODULES.XLSX"
	NOTE: THIS DO-FILE IS BASED ON A DRAFT VERSION OF THE PRO-WEAI AND IS SUBJECT TO CHANGE. */

	
********************************************************************************


clear all
set more off

********************************************************************************
					*** OPEN FILE AND LOG *** 
********************************************************************************

** Set working directory
cd "[working directory file path]"

** Store project name
global projectname "[projectname]"

** Open log
capture log close
log using "${projectname}_proweai_dataprep_log", text replace 

** Open file with pro-WEAI data
use [filename], clear

********************************************************************************
						*** PREPARE DATA *** 
********************************************************************************

* Generate identification variables
	// Note: g1_01 and g1_02 should be numeric variables
	
	capture drop hhid mid sex hh_type
	
	ren g1_01 hhid // household ID number
	ren g1_02 mid // member ID number
	ren g1_03 sex // sex of respondent
	ren g1_04 hh_type // household type
	
* Check data structure

	* Household ID and member ID should uniquely identify the observations 
	* I.e., No two households should have the same hhid; no two members in a household should have the same mid.
	isid hhid mid 
	
	* The dataset should contain only dual adult and female adult only households.
	* Female adult only households should not contain an adult male. 
	* There should be no missing observations for household type or sex.
	tab hh_type sex, mis
	
	* The dataset should contain 1-2 observations per household (1 female and 0-1 males).
	egen hhcount=count(sex), by(hhid)
	tab hhcount sex, mis


********************** GENERATE A-WEAI INDICATORS ******************************

* production / input in productive decisions
	* at least TWO agricultural activities
		* SOLELY/JOINTLY makes the decision (G2.02) OR
		* has SOME input in the decision (G2.03) OR
		* feels to MEDIUM extent could make the decision if wanted to (G2.04) 

		* Store activity label stubs in globals for variable labelling
			global act_a "staple grain farming"
			global act_b "high value crop farming"
			global act_c "large livestock raising"
			global act_d "small livestock raising"
			global act_e "poultry and small animal raising"
			global act_f "fishpond"
			global act_g "non-farm activity"
			global act_h "wage & salary employment"	
			global act_i "large purchases"
			global act_j "routine purchases"

		**G2.01 - participate in activities**
			* Indicator - respondent participated in an activity
				foreach x in a b c d e f g h {
					gen partact_`x'=(g2_01_`x'==1) if g2_01_`x'!=.
					
					label val partact_`x' yesno	
					label var partact_`x' "Respondent participated in ${act_`x'}"
					}

		* Count of activites in which respondent participated (all and agricultural only)
			egen partact=rowtotal(partact_*), missing
			label var partact "Number of activities in which individual participates"
			
			egen partactagr=rowtotal(partact_a partact_b partact_c partact_d partact_e partact_f), missing
			label var partactagr "Number of agricultural activities in which individual participates"	


	*** Sub-indicator 1: Input in decisionmaking 
		// Adequate if respondent has at least some decisionmaking power

		**G2.02
			* Create a binary variable to identify whether the respondent made the decision (by themself or joint)  
				foreach x in a b c d e f g h i j {
					gen self_`x'=((g2_02_id1_`x'==mid | (g2_02_id2_`x'==mid) | (g2_02_id3_`x'==mid)))
					}
					/*add before final parenthesis if more decisionmakers recorded: | (g2_02_id4_`x'==mid) | (g2_02_id5_`x'==mid) */	  			
					
		**G2.03 
			* Indicator - respondent has input in decsionmaking about activitiy
				foreach x in a b c d e f g h {
					gen inputdec_`x'=(g2_03_`x'>1 & g2_03_`x'<98) & partact_`x'==1 //did not make decision but had some input
					replace inputdec_`x'=1 if self_`x'==1 & partact_`x'==1 //respondent made decision
					replace inputdec_`x'=. if g2_03_`x'==. & partact_`x'==0
					replace inputdec_`x'=. if g2_02_id1_`x'==. & g2_02_id2_`x'==. & g2_02_id3_`x'==. & g2_03_`x'==. & partact_`x'==.
					replace inputdec_`x'=. if g2_02_id1_`x'==. & g2_02_id2_`x'==. & g2_02_id3_`x'==. & g2_03_`x'==. & partact_`x'==1  // Set missing those who participate (partact_==1) no decision information  
					
				* label variable
					label val inputdec_`x' yesno
					label var inputdec_`x' "Has some input in decisions regarding ${act_`x'}"
					}	


	*** Sub-indicator 2: Feel can participate in decisionmaking 
		// Adequate if respondent feels they can make decisions to a medium extent (G2_04) 
		// or respondent actually makes decision	(G2_02)

		**G2.04 
			* Indicator - respondent feels they could participate in decsionmaking about activitiy
				foreach x in a b c d e f g h i j {
					gen feelmakedec_`x'=(g2_04_`x'>2) //feel like they could participate in decisionmaking
					
					replace feelmakedec_`x'=1 if self_`x'==1  //respondent made decision
					replace feelmakedec_`x'=. if self_`x'!=1 & g2_04_`x'==.
					replace feelmakedec_`x'=. if g2_02_id1_`x'==. & g2_02_id2_`x'==. & g2_02_id3_`x'==. & g2_04_`x'==.
					
				* label variable
					label val feelmakedec_`x' yesno
					label var feelmakedec_`x' "Can participate at least small extent in decisions abt ${act_`x'}"
					}
				
	*AGGREGATION
	*INPUT IN PRODUCTIVE DECISIONS: adequate if there is AT LEAST TWO domains in which individual has some input in decisions, 
	*or makes the decision, or feels he/she could make it if he/she wanted
		capture drop feelinputdecagr
		egen feelinputdecagr_sum=rowtotal(feelmakedec_a feelmakedec_b feelmakedec_c feelmakedec_d feelmakedec_e feelmakedec_f ///
				inputdec_a inputdec_b inputdec_c inputdec_d inputdec_e inputdec_f), missing 
		
		gen feelinputdecagr=(feelinputdecagr_sum>1)
		replace feelinputdecagr=. if feelinputdecagr_sum==.
		
		label var feelinputdecagr_sum "No. agr. domains individual has some input in decisions or feels can make decisions"
		label var feelinputdecagr "Has some input in decisions or feels can make decisions in AT LEAST TWO domains"

	drop self_*

* resources / ownership of assets
	* SOLELY/JOINTLY owns at least TWO small assets or ONE large asset (incl. land) (G3.05, G3.06, G3.07)

	gen ownland=(g3_05<4 & g3_05>=1) if !missing(g3_05)
		replace ownland=(own_land==1) if !missing(own_land) & project=="jprwee"
	foreach x in a b c d e f g h i j k l m {
		gen own_`x'=(g3_06_`x'==1) if !missing(g3_06_`x')
		}
					
	egen own_sum=rowtotal(own_a-own_m ownland), missing
	foreach x in a b c d e f g h i j k l m {
		gen selfjointown_`x'=(g3_07_`x'<4) if !missing(g3_07_`x')
		}

	egen smallasset=rowtotal(selfjointown_c selfjointown_e selfjointown_j), missing
	egen largeasset=rowtotal(selfjointown_a selfjointown_b selfjointown_d selfjointown_f selfjointown_g selfjointown_h selfjointown_i selfjointown_k selfjointown_l selfjointown_m ownland), missing
	gen assetownership=(smallasset>1 | largeasset>0) if !missing(smallasset) & !missing(largeasset)
	replace assetownership=. if own_sum==.
	replace assetownership=0 if own_sum==0 | (smallasset==2 & largeasset==1 & ownland==0)


* resources / access to and decision-making over credit
	* belongs to a household that used a source of credit in the past year (G3.09) AND
	* participated in at least one decision about it (G3.10, G3.11) 
		//OR
	* belons to a household that has access to credit but did not use credit in the past year

	foreach x in a b c d e f {
		gen creditaccess_`x'=(g3_08_`x'==1 | g3_08_`x'==3) if !missing(g3_08_`x') /*yes/maybe has access to credit*/
		}
	egen creditaccess=rowtotal(creditaccess_*), missing
	capture drop credituse_*
	foreach x in a b c d e f {
		gen credituse_`x'=(g3_09_`x'==1 | g3_09_`x'==2 | g3_09_`x'==3) if !missing(g3_09_`x') /*used credit*/
		}
	egen credituse=rowtotal(credituse_*), missing
	foreach x in a b c d e f {
		gen creditdec_`x'=(g3_10_id1_`x'==mid | g3_10_id2_`x'==mid | g3_10_id3_`x'==mid | g3_11_id1_`x'==mid | g3_11_id2_`x'==mid | g3_11_id3_`x'==mid)
		replace creditdec_`x'=. if (g3_10_id1_`x'==. & g3_10_id2_`x'==. & g3_10_id3_`x'==. & g3_11_id1_`x'==. & g3_11_id2_`x'==. & g3_11_id3_`x'==.) /*solely/jointly made a decision on credit used*/
		}
	foreach x in a c b d e f {
		gen creditusedec_`x'=(credituse_`x'==1 & creditdec_`x'==1) if !missing(credituse_`x') & !missing(creditdec_`x')
		replace creditusedec_`x'=0 if creditaccess_`x'==0
		}
	egen creditsum=rowtotal(creditusedec_a-creditusedec_f), missing
	gen credit_accdec=(creditsum>0) if !missing(creditsum)
	replace credit_accdec=. if creditaccess==. | credituse==. /*missing if no info about credit access or use*/
	replace credit_accdec=0 if creditsum==0 | creditaccess==0 | credituse==0 /*in adequate if did no use credit, did not have access to credit, or did not make decisions on credit*/
	replace credit_accdec=1 if credituse==0 & creditaccess>0 /*except, adequate if did not use credit but yes/maybe had access*/

* income / control over use of income

	**G2.07
		* Indicator - respondent has input in decsionmaking on how to use income generated from activity
			capture drop incomedec_*
			foreach x in a b c d e f g h {
				gen incomedec_`x'=(g2_07_`x'>1 & g2_07_`x'<98) 
				replace incomedec_`x'=. if g2_02_id1_`x'==. & g2_02_id2_`x'==. & g2_02_id3_`x'==. & g2_07_`x'==. & partact_`x'==1
			* label variable
				label val incomedec_`x' yesno
				label var incomedec_`x' "Has some input in decisions on how to use income generated from ${act_`x'}"
			}
			foreach x in i j {
				gen incomedec_`x'=(g2_07_`x'>1 & g2_07_`x'<98) 
				replace incomedec_`x'=. if g2_02_id1_`x'==. & g2_02_id2_`x'==. & g2_02_id3_`x'==. & g2_07_`x'==. 
			* label variable
				label val incomedec_`x' yesno
				label var incomedec_`x' "Has some input in decisions on how to use income generated from ${act_`x'}"
			}
			
	*AGGREGATION
	*CONTROL OVER USE OF INCOME: adequate if there is AT LEAST ONE domain in which individual has some input in income decisions or feels she/he can make decisions regarding wage, employment and minor hh 
	*expenditures; as long the only domain in which the individual feels that he/she makes decisions IS NOT minor household expenditures
		
		egen incomedec_sum=rowtotal(incomedec_a incomedec_b incomedec_c incomedec_d incomedec_e incomedec_f incomedec_g incomedec_h ///
				feelmakedec_g feelmakedec_h feelmakedec_i feelmakedec_j), missing
		
		gen incdec_count=(incomedec_sum>0)
			replace incdec_count=0 if incdec_count==1 & incomedec_sum==1 & feelmakedec_j==1
			replace incdec_count=. if incomedec_sum==.
		
		label var incomedec_sum "No. domains individual has some input in income decisions or feels can make decisions"
		label var incdec_count "Has some input in income dec or feels can make dec AND not only minor hh expend"
		ren incdec_count incomecontrol 
	
* leadership / group membership
	* active member of at least one group

	drop group*
	foreach x in a b c d e f g h i {
		gen group_`x'=(g5_01_`x'==1) if !missing(g5_01_`x')
		}
	foreach x in a b c d e f g h i {	
		gen groupmember_`x'=(g5_03_`x'==1) if !missing(g5_03_`x') & g5_01_`x'==1 // Respondent is active group member (if group exists)
		}
	egen groupsum=rowtotal(group_*), missing
	egen groupmembersum=rowtotal(groupmember_*), missing
	gen groupmember=(groupmembersum>0) if !missing(groupmembersum)
	replace groupmember=. if groupsum==.
	replace groupmember=0 if groupsum==0

* time / workload
	* works less than 10.5 hours per day
		* workload=primary activity+(1/2)childcare

	gen workload=(1/60)*(time_work)
	gen workload105=(workload<10.5) if !missing(workload)


********************** RENAME INDICATORS ***************************************

** Rename indicators to match A-WEAI calculation file

	* Input in productive decisions: feelinputdecagr
	* Ownership of assets: jown_count
		ren jown_count assetownership
	* Access to and decisions on credit: credjanydec_any
		ren credit_accdec credjanydec_any
	* Control over use of income: incdec_count
		ren incomecontrol incdec_count
	* Group membership: groupmember_any
		ren groupmember groupmember_any
	* Workload: npoor_z105
		ren workload105 npoor_z105

********************** SAVE DATA ***********************************************

	save "${projectname}_aweai_indicators.dta", replace
